@@ -5,7 +5,7 @@
   11-OCT-1996
 */
 
-#import <swarmobject.h>
+#import <objectbase/SwarmObject.h>
 #import <simtools.h>
 
 
