@@ -6,7 +6,7 @@
 
 */
 
-#import <swarmobject.h>
+#import <objectbase/SwarmObject.h>
 #import <simtools.h>
 
 @interface AgentManager : SwarmObject {
