@@ -11,6 +11,9 @@
 #import "SCLGlobals.h"
 #import "SCLModelSwarm.h"
 
+#import "AgentManager.h"
+#import "PRNG.h"
+
 #import "Hole.h"
 #import "Substrate.h"
 #import "Link.h"
@@ -110,7 +113,7 @@ static double productionProbability = 1.0;
   return self;
 }
 
--drawSelfOn: (Raster *) r {
+-drawSelfOn: (id <Raster>) r {
   /* 
     Default particle is a 3x3 square.
     Subclasses may override to get different shapes...
