@@ -17,7 +17,7 @@
   26-SEP-1996
 */
 
-#import <space.h>
+#import <space/Discrete2d.h>
 
 @interface DiscreteToroid: Discrete2d 
 
