@@ -23,6 +23,6 @@
 
 
 
--drawSelfOn: (Raster *) r;
+-drawSelfOn: (id <Raster>) r;
 
 @end
