@@ -32,7 +32,7 @@ static Color holeColor;
   return(holeColor);
 }
 
--drawSelfOn: (Raster *) r {
+-drawSelfOn: (id <Raster>) r {
   /* Raster is cleared anyway: so we don't have to
      *do* anything to redraw a hole... */
 
