@@ -11,6 +11,9 @@
 #import "SCLGlobals.h"
 #import "SCLModelSwarm.h"
 
+#import "AgentManager.h"
+#import "PRNG.h"
+
 #import "Hole.h"
 #import "Substrate.h"
 #import "Bond.h"
@@ -30,7 +33,7 @@ static Color disintegratingColor;
 */
 
 +(void) setupProbeMap: (id) aZone {
-  ProbeMap * probeMap;
+  id <ProbeMap> probeMap;
 
   probeMap = [probeLibrary getProbeMapFor: [self class]];
 
@@ -318,6 +321,7 @@ static double emissionProbability;
   default:
     [InternalError raiseEvent:
      "Out-of-range neighbor (%d) encountered.\n", neighbor];
+    bond = (Bond *) nil; // Defensive...
   }
 
   return bond;
@@ -338,6 +342,7 @@ static double emissionProbability;
   default:
     [InternalError raiseEvent:
      "Out-of-range neighbor (%d) encountered.\n", neighbor];
+    orientation = NorthSouth; // Defensive...
   }
 
   return orientation;
@@ -356,9 +361,12 @@ static double emissionProbability;
     [self setBond: bond atNeighbor: neighbor];
   }
   else
+  {
     [InternalError raiseEvent: 
       "Attempt to create illegal bond at neighbor %d of link %d.\n",
       neighbor, self];
+    bond = (Bond *) nil; // Defensive...
+  }
 
   return bond;
 }
@@ -481,6 +489,7 @@ static double emissionProbability;
 		default:
 		  [InternalError raiseEvent:
 		    "Invalid combinedBondCount: %d \n", combinedBondCount];
+		  bondingProbability = 0.0; // Defensive...
 	      }
 	      if ([prng getTossWithProb: bondingProbability]) {
 		bond = [neighborLink createBondToNeighbor: oppositeNeighbor];
@@ -687,13 +696,15 @@ static double emissionProbability;
   return self;
 }
 
--drawSelfOn: (Raster *) r {
+-drawSelfOn: (id <Raster>) r {
   int rasterX, rasterY;
 
   if ((particleColor == linkColor) || 
       (particleColor == disintegratingColor)) 
+  {
     if (disintegrating) particleColor = disintegratingColor;
       else particleColor = linkColor;
+  }
 
   rasterX = (8 * x);
   rasterY = (8 * y);
@@ -733,7 +744,7 @@ static double emissionProbability;
   return self;
 }
 
--saveTo: (OutFile *) file {
+-saveTo: (id <OutFile>) file {
   /* Note that we do *not* save bond information here; that info
      is already implicit in the bond agent list; of course, it
      would be more conservative to save the redundancies and then
@@ -750,7 +761,7 @@ static double emissionProbability;
   return self;
 }
 
--loadFrom: (InFile *) file {
+-loadFrom: (id <InFile>) file {
   int intFlag;
 
   [super loadFrom: file];
