@@ -6,7 +6,7 @@
 
 */
 
-#import <swarmobject.h>
+#import <objectbase.h>
 
 #import "neighbor.h"
 
