@@ -5,7 +5,7 @@
    07-Jan-1997
 */
 
-#import <swarmobject.h>
+#import <objectbase/SwarmObject.h>
 #import <simtools.h>
 
 @interface PRNG: SwarmObject {
