@@ -8,7 +8,7 @@
 */
 
 
-#import <space.h>
+#import <space/Object2dDisplay.h>
 
 
 @interface SCLDisplay : Object2dDisplay
@@ -18,3 +18,9 @@
 -makeProbeAtX: (int) rasterX Y: (int) rasterY;
 
 @end
+
+
+
+
+
+
