@@ -1,5 +1,5 @@
 
-#import <simtools.h>
+#import <simtoolsgui.h>
 
 #import "SCLDisplay.h"
 
@@ -21,7 +21,9 @@
     if (obj)
       [probeDisplayManager createProbeDisplayFor: obj];
     else
-      [globalTkInterp eval: "bell"];
+      [WarningMessage raiseEvent: 
+      "Object2dDisplay: no object at coordinates(%d,%d)\n", 
+      worldX, worldY];
   } else {
     [WarningMessage raiseEvent: 
     "Object2dDisplay: invalid coordinates to make probe (%d,%d)\n", 
