@@ -6,8 +6,8 @@
 
 */
 
-#import <simtools.h>
-
+#import <simtoolsgui.h>
+#import <simtoolsgui/GUISwarm.h>
 
 #import "VNneighbor.h"
 #import "DiscreteToroid.h"
