@@ -9,6 +9,9 @@
 #import <simtools.h>
 
 #import "SCLGlobals.h"
+
+#import "PRNG.h"
+
 #import "VNneighbor.h"
 #import "MooreNeighbor.h"
 #import "SCLDisplay.h"
@@ -47,7 +50,7 @@
      created, and before the user gets a change to override
      the defaults... */
 
-  colormap = [XColormap create: [self getZone]];
+  colormap = [Colormap create: [self getZone]];
 
   [colormap setColor: 0 ToName: "white"];
   [worldManager setBackgroundColor: 0];
@@ -72,13 +75,6 @@
   [colormap setColor: 6 ToName: "cyan"];
   [colormap setColor: 7 ToName: "black"];
   
-
-  // Instruct the control panel to wait for a button event: we halt here
-  // until someone hits a control panel button so the user can get a
-  // chance to fill in parameters before the simulation runs...
-  // [controlPanel setStateStopped];
-  // [worldManager createDefaultWorld];
-
   return self;
 }
 
@@ -93,7 +89,7 @@
 */
 
 -step {
-  [controlPanel doTkEvents];
+  [actionCache doTkEvents];
   [parameterManager step];
   [worldManager step];
 
@@ -134,8 +130,12 @@
 
   //  if (getTopLevelActivity()) 
   //  [getTopLevelActivity() stop]; 
-  [controlPanel setState: ControlStateStopped];
-  
+
+  if ([controlPanel getState] != ControlStateStopped)
+    [controlPanel setStateStopped];
+
+  //  [controlPanel setState: ControlStateStopped];
+
   return self;
 }
 
