@@ -34,7 +34,7 @@ static Color substrateColor = 1;
 }
 
 
--drawSelfOn: (Raster *) r {
+-drawSelfOn: (id <Raster>) r {
   int rasterX, rasterY;
 
   rasterX = (8 * x) + 1;
