@@ -8,13 +8,10 @@
 
 #import "CellEditor.h"
 
-@interface UserCellEditor : CellEditor {
-  id probeDisplay;
-}
+@interface UserCellEditor : CellEditor
 
 -createEnd;   // Overridden...
 -update;      // Overridden...
--(void) drop; // Overridden...
 
 @end
 
