@@ -6,7 +6,7 @@
 
 */
 
-#import <simtools.h>
+#import <simtoolsgui.h>
 
 #import "UserCellEditor.h"
 
@@ -14,7 +14,7 @@
 
 -createEnd {
   UserCellEditor *finalSelf;
-  ProbeMap * probeMap;
+  id <ProbeMap> probeMap;
 
   finalSelf = [super createEnd];
 
