@@ -16,7 +16,7 @@
 
 */
 
-#import <swarmobject.h>
+#import <objectbase/SwarmObject.h>
 
 #import "NeighborhoodProtocol.h"
 #import "neighbor.h"
