@@ -6,7 +6,7 @@
 
 */
 
-#import <swarmobject.h>
+#import <objectbase/SwarmObject.h>
 
 @interface Version: SwarmObject
 
