@@ -6,8 +6,8 @@
 
 */
 
-#import <swarmobject.h>
-#import <simtools.h>
+#import <objectbase/SwarmObject.h>
+#import <gui.h>
 
 @interface WorldManager : SwarmObject {
   unsigned worldTime;
