@@ -7,6 +7,7 @@
 */
 
 #import <simtools.h>
+#import <simtoolsgui.h>
 
 #import "SCLGlobals.h"
 #import "SCLDisplay.h"
@@ -20,6 +21,9 @@
 
 #import "CellEditor.h"
 #import "UserCellEditor.h"
+#import "AgentManager.h"
+#import "ParticleManager.h"
+#import "PRNG.h"
 
 #import "WorldManager.h"
 
@@ -28,8 +32,8 @@
 
 +createBegin: (id) aZone {
   WorldManager * finalSelf;
-  MessageProbe *messageProbe;
-  ProbeMap * probeMap;
+  id <MessageProbe> messageProbe;
+  id <ProbeMap> probeMap;
 
   finalSelf = [super createBegin: aZone];
 
@@ -731,7 +735,7 @@
   return self;
 }
 
--saveTo: (OutFile *) outFile {
+-saveTo: (id <OutFile>) outFile {
   [outFile putString: "# World state...\n"];
 
   [prng saveTo: outFile];
@@ -757,7 +761,7 @@
 }
 
 
--loadFrom: (InFile *) inFile {
+-loadFrom: (id <InFile>) inFile {
   int intParm;
   int xSize, ySize;
   // char c;
@@ -803,7 +807,7 @@
 }
 
 -saveToFileNamed: (char *) filename {
-  OutFile *outFile;
+  id <OutFile> outFile;
 
   [modelSwarm setStateStopped]; // Defensive...
 
@@ -821,7 +825,7 @@
 }
 
 -loadFromFileNamed: (char *) filename {
-  InFile *inFile;
+  id <InFile> inFile;
 
   [modelSwarm setStateStopped]; // Defensive...
 
